*=====================================================*
* Requirements:                                       *
* Data files -- final_data.dta states_coordinates.dta *
*  states_data.dta cty_status.dta US_counties.dta 	  *
*  UScounties_coordinates.dta nayro14.csv   		  *
* Stata programs -- spmap scheme-lean1  regsave       *
* Instructions:										  *
* 1. type "do final_tables" in command line to load   *
*	programs										  *
* 2. type "generate_tables" in command line			  *
*   to generate latex code for tables appearing 	  *
*   in paper without Title IV SO2					  *
* 3. type "generate_tables_so2" in command line		  *
*   to generate latex code for tables appearing 	  *
*   in paper with Title IV SO2	    				  *
*=====================================================*



set more off, permanently
set matsize 10000

capture program drop generate_figures
program generate_figures
	glo so2 
	glo arp_so2 
	global nocaa i.region#i.year#i.fuel_tv i(2 3).yyyy#i0.ioudum  1.ioudrg  
	global cla i.NOx_RACT##i.yy  i.yyy##i.alt_non i.yyy##1.SCAQMD $nocaa 1.arp_nox ${arp_so2} //    
	global non i.o3_non_otr##i.yy i.yyy##i.alt_non 1.arp_nox ${arp_so2} $nocaa
	global cluster cluster_state 
	//define var labels 
	glo sum_lab  ln_mwh "Log~generation~(MWh)" ln_labor "Log~employment"	///
			coal_dum "Coal" gas_dum "Gas" muni "Muni" ioudrg_dum "Restructured" ///
			ln_ncap "Log~capacity~(MW)"  ///
			plant_age "Oldest~unit~(years)" alt_non "PM~or~SO\subscript{2}~nonattainment" ///
			title_iv_nox "Title~IV~NOx" 
	// variables that appear in summary statistics tables
	glo sum_vars ln_labor ln_mwh  ln_ncap  plant_age muni ioudrg_dum coal_dum gas_dum alt_non title_iv_nox 
	
	global graph_settings_l msymbol(i i i) connect(l l l)   ///
			lcolor (black black black) lw(medium thick medium) lpattern(dash solid dash) ///
			graphregion(fcolor(white) margin(large) lcolor(white) ) ///
			plotregion(fcolor(white) m(zero) lcolor(white)) ///
			ylabel(-.25(.25).25, nogrid labsize(vhuge) ) ytick(, tlw(vthick)) ymtick(##2, tlw(thick)) ///
			xlabel(1990 1995, labsize(vhuge)) xtick(, tlw(vthick)) ///
			xtitle("") `lt2' `lt1' legend(off) ///
			yline(0, lcolor(black)) xline(1990 1993, lcolor(black)) ///
			/*aspectratio(.75, placement(left))*/ xsize(4) ysize(3) ///
			xmtick(1988(1)1998, tlw(vthick)) ysc(noline) xsc(noline)
			
	global graph_settings "${graph_settings_l}"	

	global graph_settings3 ytitle("Log employment")  xtitle("Year") ///		
		graphregion(fcolor(white) margin(large) lcolor(white) ) ///
		ylabel(, nogrid angle(horizontal))  ytick(, tlw(vthick))  ///
		xsize(4) ysize(3)	xlab(1988(2)1998) xline(1990 1993, lcolor(black))
		
	figure_1
	figure_2
	figure_3
	figure_4
	figure_5
	figure_A2
	figure_A3
end

capture program drop generate_figures_so2
program generate_figures_so2
global data final_data

	glo so2 so2
	glo arp_so2 1.arp_so2
	global nocaa i.region#i.year#i.fuel_tv i(2 3).yyyy#i0.ioudum  1.ioudrg  
	global cla i.NOx_RACT##i.yy  i.yyy##i.alt_non i.yyy##1.SCAQMD $nocaa 1.arp_nox ${arp_so2} //    
	global non i.o3_non_otr##i.yy i.yyy##i.alt_non 1.arp_nox ${arp_so2} $nocaa
	global cluster cluster_state 
	//define var labels 
	glo sum_lab  ln_mwh "Log~generation~(MWh)" ln_labor "Log~employment"	///
			coal_dum "Coal" gas_dum "Gas" muni "Muni" ioudrg_dum "Restructured" ///
			ln_ncap "Log~capacity~(MW)"  ///
			plant_age "Oldest~unit~(years)" alt_non "PM~or~SO\subscript{2}~nonattainment" ///
			title_iv_nox "Title~IV~NOx" title_iv_so2 "Title~IV~SO\subscript{2}" 
	// variables that appear in summary statistics tables
	glo sum_vars ln_labor ln_mwh  ln_ncap  plant_age muni ioudrg_dum coal_dum gas_dum alt_non title_iv_nox title_iv_so2

	global graph_settings_l msymbol(i i i) connect(l l l)   ///
			lcolor (black black black) lw(medium thick medium) lpattern(dash solid dash) ///
			graphregion(fcolor(white) margin(large) lcolor(white) ) ///
			plotregion(fcolor(white) m(zero) lcolor(white)) ///
			ylabel(-.25(.25).25, nogrid labsize(vhuge) ) ytick(, tlw(vthick)) ymtick(##2, tlw(thick)) ///
			xlabel(1990 1995, labsize(vhuge)) xtick(, tlw(vthick)) ///
			xtitle("") `lt2' `lt1' legend(off) ///
			yline(0, lcolor(black)) xline(1990 1993, lcolor(black)) ///
			/*aspectratio(.75, placement(left))*/ xsize(4) ysize(3) ///
			xmtick(1988(1)1998, tlw(vthick)) ysc(noline) xsc(noline)
			
	global graph_settings "${graph_settings_l}"	

	global graph_settings3 ytitle("Log employment")  xtitle("Year") ///		
		graphregion(fcolor(white) margin(large) lcolor(white) ) ///
		ylabel(, nogrid angle(horizontal))  ytick(, tlw(vthick))  ///
		xsize(4) ysize(3)	xlab(1988(2)1998) xline(1990 1993, lcolor(black))
		
	figure_1
	figure_2
	figure_3
	figure_4
	figure_5
	figure_A2
	figure_A3
end



	
	



capture program drop figure_1
program figure_1

		clear
		clear matrix
				
		graph set window fontface "Times New Roman"
		set scheme lean1
		use $data , clear
		keep  ln_labor year lon lat plantid o3tv* state fips
		replace lon=-lon if lon > 0		
		*generate map data
		keep if year == 1993
		gen otr = 0
		replace otr = (state == "CT" | state == "DC" | state == "DE" |  state == "MA" | state == "MD"| state == "ME" | ///
				state == "NH" | state == "NJ" | state == "NY" | state == "PA" | state == "RI" | state == "VT" )	
		keep if ln_labor != .
		keep plantid lat lon o3tv* otr fips
		gen status = o3tv_class	
		
		replace status = 5 if status == 6 & fips == 6071 //Most of San Bernardino is severe, rather than extreme	

		gen otr_RACT = ( otr==1 & (status ==0|status ==1|status==2) ) // NOxRACT only because of OTR
		
		
		drop o3* otr	
		*(Dade cty became Miami-Dade)
		replace fips = 12086 if fips==12025 
		sort fips
		save plant_map93, replace
		*generate SD "attainment" county so will show up in map legend
		use states_coordinates, clear
		keep if _ID ==6
		replace _ID = 9999
		gen status = 0
		gen fips = 9999
		keep _ID _X _Y status
		save SD_coordinates, replace

		use states_data, clear
		keep if _ID ==6
		replace _ID = 9999
		gen status = 0
		gen fips = 9999
		keep _ID fips status
		save SD_data , replace
		
		use cty_status , clear
		keep if year == 1993
		sort fips
		keep fips status otr	
		save cty_status93 , replace

		use UScounties_data, clear
		gen long fips=real(FIPS)
		sort fips
		merge 1:1 fips using cty_status93 
		drop if _merge != 3
		drop if status == 0
		keep _ID fips status otr

		append using SD_data
		duplicates drop
		save UScounties_naa_data, replace
		sort _ID
			
		use UScounties_coordinates, clear
		merge m:1 _ID using UScounties_naa_data 
		drop if _merge != 3
		keep _ID _X _Y status otr 
		*generate nox classification
		gen nox_status = status
		replace nox_status = 0 if status == 1 |status==2 
		replace nox_status = 1 if status >2 
		save temp, replace
		drop nox_status otr
		append using SD_coordinates
		ren status byvar_pl
		save UScounties_naa_coordinates, replace
		use temp, clear
		drop if status <3
		drop status
		drop if otr == 1
		drop otr
		append using SD_coordinates
		replace nox_status = 0 if status ==0
		drop status
		ren nox_status byvar_pl
		label define nox 0 "Controls" 1 "Treatment" 
		label values byvar_pl  nox
		save UScounties_nox_coordinates, replace
		
		clear
		use states_data, clear
		gen otr = 0
			replace otr = 1 if STATE_ABBR == "CT"
			replace otr = 1 if STATE_ABBR == "DC"
			replace otr = 1 if STATE_ABBR == "DE"
			replace otr = 1 if STATE_ABBR == "MA"
			replace otr = 1 if STATE_ABBR == "MD"
			replace otr = 1 if STATE_NAME == "Maine"
			replace otr = 1 if STATE_ABBR == "NH"
			replace otr = 1 if STATE_ABBR == "NJ"
			replace otr = 1 if STATE_ABBR == "NY"
			replace otr = 1 if STATE_ABBR == "PA"
			replace otr = 1 if STATE_ABBR == "RI"
			replace otr = 1 if STATE_ABBR == "VT"
		save states_otr_data,  replace
		

		use plant_map93, clear
		gen nox_status = status
		replace nox_status = 0 if status == 1 |status==2
		replace nox_status = 1 if status >2 | otr_RACT == 1
		keep lat lon nox_status otr_RACT
		ren lat yvar_pn
		ren lon xvar_pn
		ren otr_RACT byvar_pn
		replace byvar_pn = 0 if byvar_pn == .
		gen propvar_pn = 1
		gen devvar_pn = .
		gen weightvar_pn = .


		order xvar_pn yvar_pn byvar_pn  propvar_pn  devvar_pn  weightvar_pn
		save plant_pn, replace
		
		use states_otr_data, clear
		spmap otr if STATE_NAME != "Alaska" & STATE_NAME != "Hawaii" using states_coordinates , ///
				id(_ID)  fcolor(white orange*.75) legenda(off) clmethod(unique) ///
				polygon(data(UScounties_nox_coordinates) by(byvar_pl)  ///
						fcolor(white  orange*.75 ) legenda(on)) ///
				point(data(plant_pn) x(xvar_pn) y(yvar_pn) size(small)  ///
					 by(byvar_pn) shape(O T))		
		graph export "mapnox.eps", replace fontface(Times)	
end

*Parallel trends
capture program drop figure_2
program figure_2
*keep only balanced sample to avoid distortions of large plants entering and leaving


		use $data , clear

		drop if ln_labor==.
				capture drop temp*
				gen temp = 1
				bysort plantid: egen temp2 = total(temp)
				sca temp3 = 1998 - 1987 + 1
				gen balance = (temp2==temp3)
				keep if balance == 1
		capture drop temp*
		sort plantid year
		
		bysort year: egen a = mean(ln_labor) if NOx_RACT ==0 
		bysort year: egen nNOx = mean(ln_labor) if NOx_RACT == 1 
	
		twoway (line a year if NOx_RACT == 0 , lcolor(black) ) ///
		(line nNOx year if NOx_RACT == 1, lcolor(black) lpattern(dash) ) ///
		 , ///
			${graph_settings3} legend( rows(1) region(lcolor(white))  colg(*1.5)  ///
			label(1 "Control") label(2 "Treatment" )  ///
			pos(6) )
		graph export trends_nox.eps, replace
		
		
end


capture program drop figure_3
program figure_3
	* 	single-year periods
	*Nonattainment Designation
		*	Treated group is switchers only (not accounting for OTR)
		* 	"o3_non_otr": o3 nonattainment areas,  accounting for otr
		* 	"o3_non": o3 nonattainment areas,  not accounting for otr
		*	"switch": areas that switch attainment status (ie, come into nonattainment) by 1993
		
		use $data , clear
		drop o3_non_otr
		gen o3_non_otr = o3_non*switch
		xtreg ln_labor i.o3_non_otr##b1989.year b1989.year##i.alt_non b1989.year##i.SCAQMD ///
			$nocaa 1.arp_nox ${arp_so2} , fe  vce(cluster $cluster) noomit
		est save year_sw, replace


		
		*	Treated group is switchers only (accounting for OTR)
		
		use $data , clear
		replace o3_non_otr = o3_non_otr*switch
		xtreg ln_labor i.o3_non_otr##b1989.year b1989.year##i.alt_non ///
			b1989.year##i.SCAQMD $nocaa 1.arp_nox ${arp_so2} , fe  vce(cluster $cluster) noomit
		est save year_sw_otr, replace

		
		
		*	Treated group is all nonattainment as of 1993, accounting for otr
		use $data , clear

		xtreg ln_labor i.o3_non_otr##b1989.year b1989.year##i.alt_non ///
			 b1989.year##i.SCAQMD $nocaa 1.arp_nox ${arp_so2} , fe  vce(cluster $cluster) noomit
		est save year_all, replace
	
		
	set scheme lean1
		
	*Make switch graph
	foreach i in sw sw_otr all {
		est use year_`i'
		regsave , ci 
		replace var = subinstr(var,"1o.","1.",.) 
		replace var = subinstr(var,"b.",".",.) 
		drop if substr(var,1,15) != "1.o3_non_otr#19"
		drop if substr(var,1,17) == "1.o3_non_otr#1989"
		gen yr = substr(var,-7,2)
		gen t = real(yr)
		local new = _N + 1
		set obs `new'
		replace t = 89 in l
		replace ci_lower = 0 in l
		replace ci_upper = 0 in l
		replace coef = 0 in l
		sort t
		replace t = t + 1900
		global graph_settings "${graph_settings_l}"					
		scatter ci_lower coef ci_upper t ,  ${graph_settings} ///
			saving(switch_non_`ao'`d', replace) 
		
		graph export "`i'_non${so2}.eps", replace fontface(Times)
		save non_pred${so2}, replace
	}
end

capture program drop figure_4
program figure_4
	use $data , clear
		xtreg ln_labor i.o3_class##b1989.year b1989.year##i.alt_non $nocaa ///
			 1.arp_nox ${arp_so2} , fe  vce(cluster $cluster) noomit
		
	
		est save year_cla, replace
		est sto year_cla
	forval i = 1/6 {
			 
			est use year_cla
			regsave , ci 
			replace var = subinstr(var,"1o.","1.",.) 
			replace var = subinstr(var,"b.",".",.) 
			drop if substr(var,1,13) != "`i'.o3_class#19"
			drop if substr(var,1,15) == "`i'.o3_class#1989"
			gen yr = substr(var,-7,2)
			gen t = real(yr)
			local new = _N + 1
			set obs `new'
			replace t = 89 in l
			replace ci_lower = 0 in l
			replace ci_upper = 0 in l
			replace coef = 0 in l
			sort t
			replace t = t + 1900
			global graph_settings "${graph_settings_l}"					
			scatter ci_lower coef ci_upper t ,  ${graph_settings} ///
				saving(switch_non_`ao'`d', replace) 
		
			graph export "`i'_cla${so2}.eps", replace fontface(Times)
		
			save cla`i'${so2}, replace
			if "`i'" == "1" | "`i'" == "2" save cla`i'_pred${so2}, replace
	}
	
end

capture program drop figure_5
program figure_5
	global graph_settings2 msymbol(i i i) connect(l l l)   ///
	lcolor (black black black) lw(medium thick medium) lpattern(dash solid dash) ///
	graphregion(fcolor(white) margin(large) lcolor(white) ) ///
	plotregion(fcolor(white) m(zero) lcolor(white)) ///
	ylabel(, nogrid labsize(vlarge) angle(horizontal)) ytick(, tlw(vthick)) ymtick(##2, tlw(thick)) ///
	xlabel(0 5, labsize(vlarge)) xtick(, tlw(vthick)) ///
	xtitle("") `lt2' `lt1' legend(off) ///
	yline(0, lcolor(black))  xline(0, lcolor(black)) ///
	xsize(4) ysize(3) ///
	xmtick(0(1)8, tlw(vthick)) ysc(noline) xsc(noline)	
	// run figures 3 and 4 to generate parameter estimates used to calibrate simulation
	figure_3
	figure_4
	
	
	// find counties that switch status in 2012
	// 2011 status:

	insheet using nayro14.csv, clear
	tab pollutant, missing
	keep if pollutant=="8-Hr Ozone (1997)" 
	capture drop foo
	capture drop foo2
	tostring fips_state, gen(foo) format(%02.0f)
	tostring fips_cnty, gen(foo2) format(%03.0f)
	gen str5 fips = foo + foo2
	sort fips
	rename fips fips2
	gen fips = real(fips2)
	keep fips yr2011 class
	sort fips
	*get rid of duplicates for counties with 2 classifications, use more stringent
	replace class = "Extreme" if fips == 6029 
	replace class = "Extreme" if fips == 6037 
	replace class = "Extreme" if fips == 6065
	replace class = "Extreme" if fips == 6071
	replace class = "Severe" if fips == 6095 
	replace class = "Severe" if fips == 6101  
	duplicates drop
	drop class 
	save 8hr97, replace
	//2012 status:
	insheet using nayro14.csv, clear
	keep if pollutant=="8-Hr Ozone (2008)" 
	capture drop foo
	capture drop foo2
	tostring fips_state, gen(foo) format(%02.0f)
	tostring fips_cnty, gen(foo2) format(%03.0f)
	gen str5 fips = foo + foo2
	sort fips
	rename fips fips2
	gen fips = real(fips2)
	keep fips yr2012 class
	sort fips
	*get rid of duplicates for counties with 2 classifications, use more stringent
	replace class = "Extreme" if fips == 6029 
	replace class = "Extreme" if fips == 6037 
	replace class = "Extreme" if fips == 6065
	replace class = "Extreme" if fips == 6071
	replace class = "Severe" if fips == 6095 
	replace class = "Severe" if fips == 6101  
	duplicates drop 
	merge 1:1 fips using 8hr97
	//drop counties that were in nonattainment before 2012
	drop if yr2011 == 11
	keep if yr2012 == 12
	gen cl = 2 if substr(class,1,3) == "Mar"
	replace cl = 3 if substr(class,1,3) == "Mod"
	replace cl = 4 if substr(class,1,3) == "Ser"
	replace cl = 5 if substr(class,1,3) == "Sev"
	replace cl = 6 if substr(class,1,3) == "Ext"
	drop class _merge

	save change, replace
	*now we have a list of counties that went from ozone attainment to each of 5
	*classifications. Next step is to merge with 1997 plant information to identify
	*plants in those counties
	use $data, clear
	keep ln_labor year fips otr
	sort fips
	keep if year == 1997
	drop if fips ==.
	merge m:1 fips using change
	keep if _merge ==3
	drop _merge
	//get rid of plants in otr since they did not change regulation, even if county status changed
	drop if otr==1
	*generate counterfactual employment if in non-attainment w 8-hr standard
	forval t =0/8 {
		preserve
			// use yearly regression results for nonattainment regression that accounts for otr and non-switchers
			use non_pred${so2}, clear
			sca non = coef[4+`t']
			sca nonl = ci_lower[4+`t']
			sca nonu = ci_upper[4+`t']
		restore
		//calculate point, lower, and upper bounds for plant-level employment impact by year
		gen nonemp`t' = exp(ln_labor + non)- exp(ln_labor)
		gen nonempl`t' = exp(ln_labor + nonl)- exp(ln_labor)
		gen nonempu`t' = exp(ln_labor + nonu)- exp(ln_labor)
		gen claemp`t' = 0
		gen claempl`t' = 0
		gen claempu`t' = 0
		forval v = 1/2 {
			preserve
				use cla`v'_pred${so2}, clear
				sca cla`v' = coef[4+`t']
				sca clal`v' = ci_lower[4+`t']
				sca clau`v' = ci_upper[4+`t']
			restore
				replace claemp`t' = exp(ln_labor + cla`v')- exp(ln_labor) if cl == `v'
				replace claempl`t' = exp(ln_labor + clal`v')- exp(ln_labor) if cl == `v'
				replace claempu`t' = exp(ln_labor + clau`v')- exp(ln_labor) if cl == `v'
		}
	qui summ nonemp`t'
	sca nondelta`t' = r(sum)
	qui summ nonempl`t'
	sca nondeltal`t' = r(sum)
	qui summ nonempu`t'
	sca nondeltau`t' = r(sum)
	qui summ claemp`t'
	sca cladelta`t' = r(sum)
	qui summ claempl`t'
	sca cladeltal`t' = r(sum)
	qui summ claempu`t'
	sca cladeltau`t' = r(sum)
	}
	clear
	matrix x = J(9,7,0)
	forval t = 1/8 {
		matrix x[`t'+1,1] = `t'
		matrix x[`t'+1,2] = nondelta`t'
		matrix x[`t'+1,3] = nondeltal`t'
		matrix x[`t'+1,4] = nondeltau`t'
		matrix x[`t'+1,5] = cladelta`t'
		matrix x[`t'+1,6] = cladeltal`t'
		matrix x[`t'+1,7] = cladeltau`t'
		}
	svmat x
	scatter x3 x2 x4 x1 ,  ${graph_settings2} ///								
		saving("nondelt", replace)
	graph export "nondelt${so2}.eps", replace fontface(Times)
					
	scatter x6 x5 x7 x1 ,  ${graph_settings2} ///								
		saving("cladelt", replace)
	graph export "cladelt${so2}.eps", replace fontface(Times)

end
	



capture program drop figure_A2
program figure_A2
*keep only balanced sample to avoid distortions of large plants entering and leaving
	

		use $data , clear

		drop if ln_labor==.
				capture drop temp*
				gen temp = 1
				bysort plantid: egen temp2 = total(temp)
				sca temp3 = 1998 - 1987 + 1
				gen balance = (temp2==temp3)
				keep if balance == 1
		capture drop temp*
		sort plantid year

		bysort year: egen a = mean(ln_labor) if o3_class ==0 // attainment
		bysort year: egen nNOx = mean(ln_labor) if NOx_RACT == 1 // NOx RACT
		bysort year: egen ns1m = mean(ln_labor) if s1m==1  // Subpart 1 or Marginal
		
		twoway (line a year if o3_class ==0 , lcolor(black) ) ///
		(line nNOx year if (NOx_RACT==1 ), lcolor(black) lpattern(dash) ) ///
		(line ns1m year if (s1m == 1), lcolor(black) lpattern(dot) ) ///
		 , ///
			${graph_settings3} legend( rows(2) region(lcolor(white))  colg(*1.5)  ///
			label(1 "Attainment") label(2 "NOx RACT" ) label(3 "Other O3") ///
			pos(6) )
		graph export trends_lab.eps, replace
		
		
end

capture program drop figure_A3
program figure_A3
	// To get list of deregulating states from original FRW data set run the
	// following code.
	/*
	use frw1extract_enf, clear
	bysort state: egen temp = total(st_drg)
	duplicates drop state, force
	li state if st_drg >0 & st_drg <.
	*/
	use states_data, clear
	ren STATE_ABBR state
	//some state abbreviations are missing
	replace state = "ME" if STATE_NAME == "Maine"
	replace state = "MT" if STATE_NAME == "Montana"
	gen dr = (state=="AR"|state=="AZ"|state=="CA"|state=="CT"|state=="DC"|state=="DE" ///
				|state=="IL"|state=="IN"|state=="KY"|state=="MA"|state=="MD" ///
				|state=="ME"|state=="MI"|state=="MT"|state=="NH"|state=="NJ"|state=="NM" ///
				|state=="NV"|state=="NY"|state=="OH"|state=="OK"|state=="OR"|state=="PA" ///
				|state=="RI"|state=="TX" |state=="VA"|state=="WV") 
	save states_data_dr, replace
	*use states_coordinates, clear
	spmap dr if STATE_NAME != "Alaska" & STATE_NAME != "Hawaii" using states_coordinates , ///
			id(_ID) /*fcolor(white gs11)*/ fcolor(white gs12) legenda(off) clmethod(unique) 
		
	graph export "mapdr.eps", replace fontface(Times)	
end
