*=====================================================*
* LOAD ALL MACROS BEFORE CREATING TABLES              *
* Requirements:                                       *
* Data files -- final_data.dta    					  *
* Stata programs -- esttab estout					  *
* 1. type "do final_tables" in command line to load   *
*	programs										  *
* 2. type "generate_tables" in command line			  *
*   to generate latex code for tables appearing 	  *
*   in paper without Title IV SO2					  *
* 3. type "generate_tables_so2" in command line		  *
*   to generate latex code for tables appearing 	  *
*   in paper with Title IV SO2	    				  *
*=====================================================*

set more off, permanently
set matsize 10000

capture program drop generate_tables
program generate_tables
	
*========*
* MACROS *
*========*
	global data final_data
	glo so2
	glo arp_so2
	global nocaa i.region#i.year#i.fuel_tv i(2 3).yyyy#i0.ioudum  1.ioudrg  
	global cla i.NOx_RACT##i.yy  i.yyy##i.alt_non i.yyy##1.SCAQMD $nocaa 1.arp_nox //    
	global non i.o3_non_otr##i.yy i.yyy##i.alt_non 1.arp_nox  $nocaa
	global cluster cluster_state 
	//define var labels 
	glo sum_lab  ln_mwh "Log~generation~(MWh)" ln_labor "Log~employment"	///
			coal_dum "Coal" gas_dum "Gas" muni "Muni" ioudrg_dum "Restructured" ///
			ln_ncap "Log~capacity~(MW)"  ///
			plant_age "Oldest~unit~(years)" alt_non "PM~or~SO\subscript{2}~nonattainment" ///
			title_iv_nox "Title~IV~NOx" 
	// variables that appear in summary statistics tables
	glo sum_vars ln_labor ln_mwh  ln_ncap  plant_age muni ioudrg_dum coal_dum gas_dum alt_non title_iv_nox


	table_1
	table_2
	table_3
	tables_4_A3
	table_5
	table_6
	table_A1
	table_A2
end

capture program drop generate_tables_so2
program generate_tables_so2

*========*
* MACROS *
*========*
	global data final_data
	glo so2 so2
	glo arp_so2 1.arp_so2
	global nocaa i.region#i.year#i.fuel_tv i(2 3).yyyy#i0.ioudum  1.ioudrg  
	global cla i.NOx_RACT##i.yy  i.yyy##i.alt_non i.yyy##1.SCAQMD $nocaa 1.arp_nox 1.arp_so2 //    
	global non i.o3_non_otr##i.yy i.yyy##i.alt_non 1.arp_nox 1.arp_so2 $nocaa
	global cluster cluster_state 
	//define var labels 
	glo sum_lab  ln_mwh "Log~generation~(MWh)" ln_labor "Log~employment"	///
			coal_dum "Coal" gas_dum "Gas" muni "Muni" ioudrg_dum "Restructured" ///
			ln_ncap "Log~capacity~(MW)"  ///
			plant_age "Oldest~unit~(years)" alt_non "PM~or~SO\subscript{2}~nonattainment" ///
			title_iv_nox "Title~IV~NOx" title_iv_so2 "Title~IV~SO\subscript{2}" 
	// variables that appear in summary statistics tables
	glo sum_vars ln_labor ln_mwh  ln_ncap  plant_age muni ioudrg_dum coal_dum gas_dum alt_non title_iv_nox title_iv_so2
	table_1
	table_2
	table_3
	tables_4_A3
	table_5
	table_6
	table_A1
	table_A2
end



*=========*
* Tables  *
*=========*

capture program drop table_1
program table_1
	use  $data , clear
	
	//generate pre-treatment means
	keep if year>1986 & year <1990
	//generate difference in logs from two years prior	
	foreach i in ln_mwh ln_labor ln_ncap plant_age {
		gen pre_dif_`i' = `i'-l2.`i'
	}
	//generate average variable values over pre-treatment period
	foreach i of glo sum_vars { 
		bysort plantid: egen pre_`i' = mean(`i') 
		drop `i'
		ren pre_`i' `i'
	}
	bysort plantid: egen pre_NOx_RACT = mean(NOx_RACT) //maintains treatment classification
	//for years with missing data
	drop NOx_RACT
	ren pre_NOx_RACT NOx_RACT
	keep if year == 1989
	//create summary stat table: NOx RACT treatment v control
	eststo clear

	
	//controls
		estpost tabstat $sum_vars ///			
		if NOx_RACT==0 & ln_labor !=. , ///
			stat(mean sd)  columns(statistics)  
		eststo cm
		
		sca n_c = e(N)

	//treatment
		estpost tabstat $sum_vars ///
			if NOx_RACT==1 & ln_labor !=. , ///
			stat(mean sd)  columns(statistics)
		eststo tm
		sca n_t = e(N)
		
		estpost ttest $sum_vars ///
			if ( NOx_RACT == 0 | NOx_RACT == 1 ) & ln_labor !=. , by(NOx_RACT) unequal
			matrix mean=e(b)
			estadd matrix mean
			matrix sd=e(t)
			estadd matrix sd
		eststo tct
	// differences from 1987-1990
	// controls
		drop ln_mwh ln_labor ln_ncap  plant_age
		renvars pre_dif_ln_mwh pre_dif_ln_labor pre_dif_ln_ncap  pre_dif_plant_age \ ///
			ln_mwh ln_labor ln_ncap  plant_age
		estpost tabstat ln_labor ln_mwh ln_ncap   plant_age  ///			
		if NOx_RACT==0 & ln_labor !=. , ///
			stat(mean sd)  columns(statistics)  
		eststo cd
		sca n_cd = e(N)
	// treatment
		estpost tabstat ln_labor ln_mwh ln_ncap   plant_age   ///
			if NOx_RACT==1 & ln_labor !=. , ///
			stat(mean sd)  columns(statistics)
		eststo td
		
		sca n_td = e(N)
		
		estpost ttest ln_labor ln_mwh ln_ncap   plant_age if (NOx_RACT == 0 | NOx_RACT == 1) ///
			& ln_labor !=. , by(NOx_RACT) unequal
			matrix mean=e(b)
			estadd matrix mean
			matrix sd=e(t)
			estadd matrix sd
		eststo tctd

		capture file close latex
		file open latex using non_obs${so2}.txt, write replace
			file write latex "Plants & \multicolumn{1}{c}{" (n_t) "} & \multicolumn{1}{c}{" (n_c) "}" 
			file write latex " \\" _n
		file close latex
		file open latex using non_obsb${so2}.txt, write replace
			file write latex "Plants & \multicolumn{1}{c}{" (n_td) "} & \multicolumn{1}{c}{" (n_cd) "}" 
			file write latex " \\" _n
		file close latex
		esttab tm cm  tct  using sumstat${so2}.tex, main(mean) b(%5.3f) aux(sd) star unstack nonum nonote ///
			varlabels(${sum_lab}) ///
			nomtitles  ///
			booktabs alignment(.) width(\hsize) replace type  ///
				noline  nogaps fragment 	noobs not label
		esttab td cd  tctd using sumstatb${so2}.tex, main(mean) b(%5.3f) aux(sd) star unstack nonum nonote ///
			varlabels(${sum_lab}  ) ///
			nomtitles  ///
			booktabs alignment(.) width(\hsize) replace type  ///
				noline  nogaps fragment 	noobs not label
		eststo clear
	
end 

capture program drop table_2
program table_2
	use $data, clear
	drop if ln_labor == .
	foreach i in labor mwh {
		xtreg ln_`i' $cla  , fe  vce(cluster $cluster ) noomit
		est save class_`i', replace
		sca n=e(N)
		sca ng = e(N_g)
		file open latex using n${so2}.txt, write replace
			file write latex (n)
		file close latex
		file open latex using ng${so2}.txt, write replace
			file write latex (ng)
		file close latex 		
	}
		
	est clear
	foreach i in labor mwh {
		foreach j in  class_`i'   {
			est use `j'
			est sto `j'
		}
	}

	esttab   class_labor class_mwh /// 
		using labor_table${so2}, b(%9.3f) not noobs se(%9.3f) star(* .10 ** .05 *** .01)   ///	
		noline nogaps fragment nonum nomtitles	 sub(\_3 O$_3$ ) ///
		booktabs alignment(.) width(\hsize) replace type ///
		keep(1.NOx_RACT#2.yy 1.NOx_RACT#3.yy ///
			2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
			1.ioudrg 2.yyyy#0.ioudum  3.yyyy#0.ioudum ///	
			 1.arp_nox ${arp_so2} 2.yyy#1.alt_non 3.yyy#1.alt_non  ) ///
		order( 1.NOx_RACT#2.yy 1.NOx_RACT#3.yy ///
			2.yyy#1.alt_non 3.yyy#1.alt_non ///
			2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
			1.ioudrg 2.yyyy#0.ioudum  3.yyyy#0.ioudum ///	
			 1.arp_nox ${arp_so2} ) ///	
		coef(1.NOx_RACT#2.yy "NOx~RACT~$\times$~90--92" 1.NOx_RACT#3.yy "NOx~RACT~$\times$~93--98" ///
			1.ioudrg "Restructured" 2.yyyy#0.ioudum "Muni~$\times$~90--92" 3.yyyy#0.ioudum "Muni~$\times$~93--98" ///	
			1.arp_nox "Title IV NOx"  ///
			1.arp_so2 "Title IV SO\$_2\$"  ///
			anwage_util "ln(wage)" ln_fuel_price "ln(fuel~price)"  ///
			2.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~90--92" ///
			3.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~93--98"  ///
			2.o3_class2#1988.year "NOx~RACT~$\times$~1988"  2.o3_class2#1989.year "NOx~RACT~$\times$~1989" ///
			1988.year#0.ioudum "Muni~$\times$~1988" ///
			1989.year#0.ioudum "Muni~$\times$~1989" ///
			1988.year#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~1988" ///
			1989.year#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~1989" ///
			2.yyy#1.SCAQMD "South~Coast~$\times$~90--92" 3.yyy#1.SCAQMD "South~Coast~$\times$~93--98" ) 
	
	*R2 		
	esttab  class_labor class_mwh /// 
			using labor_table_r2${so2}, b(%9.3f) r2 not noobs    ///		
			booktabs alignment(.) width(\hsize) replace type ///
			drop( * ) ///			
			noline nogaps fragment nonum nomtitles
			
	
end

capture program drop table_3
program table_3
	*Nonattainment Designation
		*	Treated group is switchers only "New O3" (not accounting for OTR)
		* 	"o3_non_otr": o3 nonattainment areas,  accounting for otr
		* 	"o3_non": o3 nonattainment areas,  not accounting for otr
		*	"switch": areas that switch attainment status (ie, come into nonattainment) by 1993
		*	multi-year periods
	*REGRESSIONS	
	use $data, clear
			
		*time invariant designation (treatment = switch)
		drop o3_non_otr
		gen o3_non_otr_sw = o3_non*switch	// treatment = switch without otr
		xtreg ln_labor i.o3_non_otr_sw##3.yy i.yyy##i.alt_non 1.arp_nox ${arp_so2} ///
			 $nocaa , fe  vce(cluster $cluster) noomit
		est save non_sw_labor, replace
		*include OTR
		use $data, clear
			*   only CFR + OTR switchers
			gen o3_non_otr_sw = o3_non_otr*switch_otr // treatment = switch with otr
			xtreg ln_labor i.o3_non_otr_sw##3.yy i.yyy##i.alt_non 1.arp_nox ${arp_so2} ///
				 $nocaa , fe  vce(cluster $cluster) noomit
			est save non_sw_otr_labor, replace
		*time varying include OTR
			use $data, clear
			xtreg ln_labor $non  , fe  vce(cluster $cluster) noomit
			est save non_labor, replace
	
		
		*include "other o3" treatment
		use $data, clear
		replace NOx_RACT = 2 if s1m == 1 
		xtreg ln_labor $cla  , fe  vce(cluster $cluster) noomit
		est save other_labor, replace
	*TABLE
	est clear
	foreach i in labor  {
		foreach j in non_sw_`i' non_sw_otr_`i' non_`i'  other_`i'  {
			est use `j'
			est sto `j'
		}
	}
	
	esttab non_sw_labor non_sw_otr_labor non_labor other_labor /// 
			using non_table${so2} , b(%9.3f) not noobs se(%9.3f) star(* .10 ** .05 *** .01)   ///	
			noline nogaps fragment nonum nomtitles	 sub(\_3 O$_3$ ) ///
			booktabs alignment(.) width(\hsize) replace type ///
			keep(1.NOx_RACT#2.yy  1.NOx_RACT#3.yy  ///
				2.NOx_RACT#2.yy  2.NOx_RACT#3.yy  ///
				1.o3_non_otr#2.yy 1.o3_non_otr#3.yy ///
				1.o3_non_otr_sw#3.yy ///
				2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
				1.ioudrg 2.yyyy#0.ioudum  3.yyyy#0.ioudum ///	
				 1.arp_nox  ${arp_so2} 2.yyy#1.alt_non 3.yyy#1.alt_non ) ///
			order(1.o3_non_otr_sw#3.yy 1.o3_non_otr#2.yy 1.o3_non_otr#3.yy ///
				1.NOx_RACT#2.yy  1.NOx_RACT#3.yy  ///
				2.NOx_RACT#2.yy  2.NOx_RACT#3.yy  ///
				2.yyy#1.alt_non 3.yyy#1.alt_non ///
				2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
				1.ioudrg 2.yyyy#0.ioudum  3.yyyy#0.ioudum ///	
				 1.arp_nox ${arp_so2} ) ///	
			coef(1.o3_non_otr_sw#3.yy "New~O\$_3\$" ///
				1.o3_non_otr#2.yy "All~O\$_3\$~$\times$~90--92" 1.o3_non_otr#3.yy "All~O\$_3\$~$\times$~93--98" ///				
				2.NOx_RACT#2.yy "Other~O\$_3\$~$\times$~90--92" 2.NOx_RACT#3.yy "Other~O\$_3\$~$\times$~93--98" ///
				1.NOx_RACT#2.yy "NOx~RACT~$\times$~90--92" 1.NOx_RACT#3.yy "NOx~RACT~$\times$~93--98" ///
				1.ioudrg "Restructured" 2.yyyy#0.ioudum "Muni~$\times$~90--92" 3.yyyy#0.ioudum "Muni~$\times$~93--98" ///	
				1.arp_nox "Title IV NOx"  ///
				1.arp_so2 "Title~IV~SO\$_2\$"  ///
				anwage_util "ln(wage)" ln_fuel_price "ln(fuel~price)"  ///
				2.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~90--92" 3.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~93--98" ///
				2.yyy#1.SCAQMD "South~Coast~$\times$~90--92" 3.yyy#1.SCAQMD "South~Coast~$\times$~93--98") 
		
	*R2 		
	esttab non_sw_labor non_sw_otr_labor non_labor other_labor  /// 
			using non_table_r2${so2}, b(%9.3f) r2 not noobs    ///		
			booktabs alignment(.) width(\hsize) replace type ///
			drop( * ) ///			
			noline nogaps fragment nonum nomtitles
		
		
end


capture program drop tables_4_A3
program tables_4_A3	
*LABOR PRODUCTIVITY ANALYSIS
*	Treated group is all nonattainment as of 1993, accounting for otr
*Nonattainment Classification
	
	use $data , clear
	summ change	
	*"change" measures epochs per plant
	*count max plant epochs
	loc cmax = r(max)
	
	preserve 
		duplicates drop plantid plantid2 change, force 
		count if plantid2 == 0
		// number of plants with 1 epoch
		sca e00 = r(N)
		forval i = 0/`cmax' {
			count if plantid2 > 0 & change == `i'
			*number of plants with `i' + 1 epochs
			sca e`i' = r(N)
		}
		sca n_e = e00
		forval i = 0/`cmax' {
			// total number of plant epochs
			sca n_e = e`i' + n_e
		}
	restore
	*record number of plant epochs
		file open latex using n_e${so2}.txt, write replace
			file write latex (n_e)
		file close latex
	
	*OLS
	xtreg ln_labor ln_mwh $cla  i.plantid2#i.change, fe  vce(cluster $cluster) noomit
	est save eff_cla, replace
	*IV using FRW instrument (state demand)
	xtset, clear
	xtset plantid year
	drop if ln_labor == .
	xtreg ln_mwh  $cla  i.plantid2#i.change lstsales, fe  vce(cluster $cluster)  noomit
	est save stage1, replace
	xtivreg ln_labor  $cla  i.plantid2#i.change (ln_mwh=lstsales) , fe  vce(cluster $cluster) noomit small
	estadd sca r2 = e(r2_w)
	est save eff_cla_iv, replace
	
	foreach i in eff_cla eff_cla_iv  stage1  {
		est use `i'
		est sto `i'
		}
	
	

	esttab  eff_cla eff_cla_iv  /// 
			using eff_table${so2}, b(%9.3f) not  noobs se(%9.3f) star(* .10 ** .05 *** .01) ///		
			booktabs alignment(.) width(\hsize) replace type sub(\_ _) ///
			order(1.NOx_RACT#2.yy 1.NOx_RACT#3.yy /// 
				2.yyy#1.alt_non 3.yyy#1.alt_non ///
				2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
				  1.ioudrg  2.yyyy#0.ioudum 3.yyyy#0.ioudum  1.arp_nox ${arp_so2} ///	
				 anwage_util ln_fuel_price ln_mwh ) 		 ///
			keep(1.NOx_RACT#2.yy 1.NOx_RACT#3.yy ///		
				1.ioudrg 2.yyyy#0.ioudum 3.yyyy#0.ioudum ///	
				 ln_mwh ///
				  2.yyy#1.alt_non 3.yyy#1.alt_non ///
				  2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
				  1.arp_nox ${arp_so2} )  ///
			coef(1.NOx_RACT#2.yy "NOx~RACT~$\times$~90--92" 1.NOx_RACT#3.yy "NOx~RACT~$\times$~93--98" ///
				1.ioudrg "Restructured" 2.yyyy#0.ioudum "Muni~$\times$~90--92" 3.yyyy#0.ioudum "Muni~$\times$~93--98" ///	
				2.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~90--92" ///
				3.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~93--98" ///
				anwage_util "ln(wage)" ln_fuel_price "ln(fuel~price)" ln_mwh "ln(MWh)" ///
				  1.arp_nox "Title IV NOx"  ///
				  1.arp_so2 "Title IV SO\$_2\$"  ///
				  2.yyy#1.SCAQMD "South~Coast~$\times$~90--92" 3.yyy#1.SCAQMD "South~Coast~$\times$~93--98") ///				 
			noline nogaps fragment nonum nomtitles
	

	esttab  stage1 /// 
			using stage1${so2}, b(%9.3f) not  noobs se(%9.3f) star(* .10 ** .05 *** .01) ///		
			booktabs alignment(.) width(\hsize) replace type sub(\_ _) /// 
			order(lstsales ///
				1.NOx_RACT#2.yy 1.NOx_RACT#3.yy ///
				2.yyy#1.alt_non 3.yyy#1.alt_non /// 
				  2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
				  1.ioudrg  1.arp_nox  ${arp_so2} ///
				   2.yyyy#0.ioudum 3.yyyy#0.ioudum ///	
				 anwage_util ln_fuel_price ln_mwh ) 		 ///
			keep(lstsales /// 
				1.NOx_RACT#2.yy 1.NOx_RACT#3.yy /// 
				  2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
				1.ioudrg 2.yyyy#0.ioudum 3.yyyy#0.ioudum ///	
				 1.arp_nox  ${arp_so2} ///
				  2.yyy#1.alt_non 3.yyy#1.alt_non  )  ///
			coef(lstsales "State sales" 1.o3_class2#2.yy "VOC~$\times$~90--92" 1.o3_class2#3.yy "VOC~$\times$~93--98" ///
				1.NOx_RACT#2.yy "NOx~RACT~$\times$~90--92" 1.NOx_RACT#3.yy "NOx~RACT~$\times$~93--98"  ///
				1.ioudrg "Restructured" 2.yyyy#0.ioudum "Muni~$\times$~91-92" 3.yyyy#0.ioudum "Muni~$\times$~93--98" ///	
				1.arp_nox "Title IV NOx"  ///
				1.arp_so2 "Title IV SO\$_2\$"   ///
				anwage_util "ln(wage)" ln_fuel_price "ln(fuel~price)" ln_mwh "ln(MWh)" ///
				  2.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~90--92" ///
				  3.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~93--98" ///
				  2.yyy#1.SCAQMD "South~Coast~$\times$~90--92" 3.yyy#1.SCAQMD "South~Coast~$\times$~93--98") ///				 
			noline nogaps fragment nonum nomtitles
		
		*R2 

	esttab eff_cla eff_cla_iv   /// 
			using eff_cla_r2${so2}, b(%9.3f) r2 not noobs    ///		
			booktabs alignment(.) width(\hsize) replace type ///
			drop( * ) ///			
			noline nogaps fragment nonum nomtitles	
			
	esttab stage1   /// 
			using stage1_r2${so2}, b(%9.3f) r2 not noobs    ///		
			booktabs alignment(.) width(\hsize) replace type ///
			drop( * ) ///			
			noline nogaps fragment nonum nomtitles
	
end

capture program drop table_5
program table_5 
	
	*REGRESSIONS
	*matching
	use ${data}, clear
	drop if ln_labor == .
		xtreg ln_labor $cla  if match_r == 1 , fe  vce(cluster $cluster) noomit
		est save class_labor_r, replace
		sca n_r=e(N)
		sca ng_r = e(N_g)
		file open latex using n_r${so2}.txt, write replace
			file write latex (n_r)
		file close latex
		file open latex using ng_r${so2}.txt, write replace
			file write latex (ng_r)
		file close latex 		
	
		

	
*	Interact various subsamples
		foreach i in ioudrg ioudum alt_non balance   {	
				use $data , clear
				drop if year ==1999	
				drop if ln_labor ==.
				capture drop temp*
				gen temp = 1
				bysort plantid: egen temp2 = total(temp)
				gen balance = (temp2==12)
				gen interact = `i'
				if "`i'" == "ioudrg" {
					* restructuring only happens after 1993, the following syntax forces stata to generate right factor variables
					xtreg ln_labor $cla  i.NOx_RACT#3.yyy#1.interact 3.yyy#1.interact , fe  vce(cluster $cluster) noomit
					sca r2=round(e(r2_w),.0001)
					sca r2_a=round(e(r2_a),.0001)
					qui _eststo temp
					qui esttab temp, se nostar
					matrix C=r(coefs)
					matrix temp2 = C["1.NOx_RACT#3.yyy#1.interact",1...]
					matrix rownames temp2 = "1.NOx_RACT#3.yy#1.interact"
					matrix C = C\temp2
					matrix b = C[1...,1]'
					eststo temp2
					ereturn post b
					matrix se = C[1...,2]'
					estadd matrix se
					estadd scalar r2
					estadd scalar r2_a
					eststo temp2, refresh
					est save class_`i', replace			
					}
				if "`i'" == "balance" {										
						keep if balance ==1
						xtreg ln_labor $cla   , fe  vce(cluster $cluster) noomit
						est save class_`i', replace
						sca n_`i' = e(N)
						sca ng_`i' = e(N_g)
				}
				if "`i'" == "ioudum" | "`i'" == "alt_non"   {
					* create dummy for Muni
					if "`i'" == "ioudum" replace interact = 1-interact 
					xtreg ln_labor $cla 1.NOx_RACT#i(2 3).yy#i.interact  , fe  vce(cluster $cluster) noomit
					est save class_`i', replace		
				}				
			}
		//	entry/exit sensitivity
		*use entex, clear
		use $data , clear
		//  replace ln_labor=0 for missing data for entrants/exits & plants w negative netgen
		replace ln_labor = ln_labor_ext
		xtreg ln_labor $cla , fe  vce(cluster $cluster) noomit
		est save class_entex, replace
		sca n_entex = e(N)
		sca ng_entex = e(N_g)
	* 	include include input prices
		use $data , clear
		xtreg ln_labor $cla  anwage_util ln_fuel_price , fe  vce(cluster $cluster) noomit
		est save class_price, replace
		sca n_price = e(N)
		sca g_price = e(N_g)
	
				*save observation numbers
		foreach i in n_entex n_price n_balance  {
		file open latex using `i'${so2}.txt, write replace
				file write latex (`i')
			file close latex
		}	
		foreach i in  ng_entex ng_balance g_price {
			file open latex using `i'${so2}.txt, write replace
				file write latex (`i')
			file close latex
		}
	


*TABLE
	est clear
		foreach j in other_labor class_labor_r class_ioudum class_ioudrg ///
			 class_price class_entex class_balance class_alt_non  {
			est use `j'
			est sto `j'
		}
		esttab class_labor_r class_ioudum class_ioudrg  class_alt_non  class_price class_entex class_balance /// 
			using rob1_table${so2}, b(%9.3f) not noobs se(%9.3f) star(* .10 ** .05 *** .01)   ///	
			noline nogaps fragment nonum nomtitles	sub(\_3 O$_3$ ) ///
			booktabs alignment(.) width(\hsize) replace type ///
			keep(1.NOx_RACT#2.yy 1.NOx_RACT#3.yy ///
				1.NOx_RACT#2.yy#1.interact 1.NOx_RACT#3.yy#1.interact ///				
				1.ioudrg 2.yyyy#0.ioudum 3.yyyy#0.ioudum 2.yyy#1.alt_non 3.yyy#1.alt_non  ///	
				2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
				1.arp_nox ${arp_so2} anwage_util ln_fuel_price  ) ///
			order(1.NOx_RACT#2.yy 1.NOx_RACT#3.yy ///
				1.NOx_RACT#2.yy#1.interact 1.NOx_RACT#3.yy#1.interact ///			
				2.yyy#1.alt_non 3.yyy#1.alt_non ///
				2.yyy#1.SCAQMD 3.yyy#1.SCAQMD ///
				1.ioudrg 2.yyyy#0.ioudum 3.yyyy#0.ioudum ///	
				1.arp_nox ${arp_so2}  anwage_util ln_fuel_price ) ///	
			coef(1.NOx_RACT#2.yy "NOx~RACT~$\times$~90--92" 1.NOx_RACT#3.yy "NOx~RACT~$\times$~93--98" ///
				1.ioudrg "Restructured" 2.yyyy#0.ioudum "Muni~$\times$~90--92" 3.yyyy#0.ioudum "Muni~$\times$~93--98" ///	
				1.NOx_RACT#2.yy#1.interact "NOx~RACT~$\times$~90--92~$\times$~Variable" ///
				1.NOx_RACT#3.yy#1.interact "NOx~RACT~$\times$~93--98~$\times$~Variable" ///	
				1.arp_nox "Title IV NOx"  ///
				1.arp_so2 "Title IV SO\$_2\$"  ///
				anwage_util "ln(wage)" ln_fuel_price "ln(fuel~price)" ///
				2.yyy#1.SCAQMD "South~Coast~$\times$~90--92" 3.yyy#1.SCAQMD "South~Coast~$\times$~93--98" ///
				2.yyy#1.alt_non "PM~or~SO\subscript{2}~nonattain~$\times$~90--92" 3.yyy#1.alt_non "PM~or~SO\subscript{2}~nonattain~$\times$~93--98")
			
		
			
	*R2 		
	esttab class_labor_r class_ioudum class_ioudrg  class_alt_non class_price class_entex class_balance /// 
			using rob1_table_r2${so2}, b(%9.3f) r2 not noobs    ///		
			booktabs alignment(.) width(\hsize) replace type ///
			drop( * ) ///			
			noline nogaps fragment nonum nomtitles	
	
end

capture program drop table_6 
program table_6
	use $data, clear
	foreach i in ext ent {
		count if `i' == 1 & year == 1987
		sca `i'_pt = r(N)
		count if `i' == 1 & ln_labor_ext == 0
		sca `i'_yr = r(N)
		file open latex using `i'_pt.txt, write replace
			file write latex (`i'_pt)
		file close latex
		file open latex using `i'_yr.txt, write replace
			file write latex (`i'_yr)
		file close latex
		*save entry/exit plants by year and nonattainment status
		forval j = 88/97 {
			forval k = 0/1 {
			count if `i'_year == 1 & year == 19`j' & NOx_RACT == `k'
			sca `i'`k'`j' = r(N)
			di "`i'`k'`j' =" `i'`k'`j'
			}
		}
	}


	foreach i in Entrants Exits {
		foreach j in Controls  "NOx RACT" {
			if "`i'" == "Entrants" loc ii ent
			if "`i'" == "Exits" loc ii ext
			if "`j'" == "Controls" loc jj 0
			if "`j'"  == "NOx RACT" loc jj 1
			file open latex using `ii'`jj'.txt, write replace
				file write latex "`j' &" (`ii'`jj'88) "&" (`ii'`jj'89) "&" (`ii'`jj'90) "&" (`ii'`jj'91)
				file write latex "&" (`ii'`jj'92) "&" (`ii'`jj'93) "&" (`ii'`jj'94)
				file write latex "&" (`ii'`jj'95) "&" (`ii'`jj'96) "&" (`ii'`jj'97) 
				file write latex " \\" _n
			file close latex
		}
	}		
end

capture program drop table_A1
program table_A1
	use $data , clear
	foreach i in labor mwh {	
		drop if year>1989
		xtreg ln_`i'  i.NOx_RACT##i.year i.year##1.alt_non i.year##1.SCAQMD i.region#i.year#i.fuel_tv  ///
			 i.year##i0.ioudum , fe  vce(cluster $cluster) noomit		
		est save class_pretreat`i', replace
		sca n_class_pretreat=e(N)
		sca ng_class_pretreat= e(N_g)
	} 
	file open latex using n_class_pretreat.txt, write replace
		file write latex (n_class_pretreat)
	file close latex
	file open latex using ng_class_pretreat.txt, write replace
		file write latex (ng_class_pretreat)
	file close latex
	est clear
	foreach i in labor mwh {
		est use class_pretreat`i'  
		est sto class_pretreat`i'
	}
	
	esttab  class_pretreatlabor  class_pretreatmwh  /// 
			using prelabor_table, b(%9.3f) not noobs se(%9.3f) star(* .10 ** .05 *** .01)   ///	
			noline nogaps fragment nonum nomtitles	 sub(\_3 O$_3$ ) ///
			booktabs alignment(.) width(\hsize) replace type ///
			keep( ///	
				 1.NOx_RACT#1988.year  ///
				1988.year#0.ioudum  1988.year#1.alt_non 1988.year#1.SCAQMD ///
			 1.NOx_RACT#1989.year  ///
				1989.year#0.ioudum  1989.year#1.alt_non 1989.year#1.SCAQMD ) ///
			order(1.NOx_RACT#1988.year 1.NOx_RACT#1989.year ///
				1988.year#1.alt_non  1989.year#1.alt_non  ///
				1988.year#1.SCAQMD 1989.year#1.SCAQMD ///
				1988.year#0.ioudum  1989.year#0.ioudum ) ///	
			coef(2.o3_class2#2.yy "NOx~RACT~$\times$~90--92" 2.o3_class2#3.yy "NOx~RACT~$\times$~93--98" ///
				1.ioudrg "Restructured" 2.yyyy#0.ioudum "Muni~$\times$~90--92" 3.yyyy#0.ioudum "Muni~$\times$~93--98" ///	
				anwage_util "ln(wage)" ln_fuel_price${eia} "ln(fuel~price)"  ///
				2.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~90--92" ///
				3.yyy#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~93--98"  ///
				 1.NOx_RACT#1988.year "NOx~RACT~$\times$~1988"   1.NOx_RACT#1989.year "NOx~RACT~$\times$~1989" ///
				1988.year#0.ioudum "Muni~$\times$~1988" ///
				1989.year#0.ioudum "Muni~$\times$~1989" ///
				1988.year#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~1988" ///
				1989.year#1.alt_non "PM~or~SO\$_2\$~nonattainment~$\times$~1989" ///
				1988.year#1.SCAQMD "South~Coast~$\times$~1988" ///
				1989.year#1.SCAQMD "South~Coast~$\times$~1989") 
		
	*R2 		
	esttab  class_pretreatlabor  class_pretreatmwh  /// 
			using prelabor_table_r2, b(%9.3f) r2 not noobs    ///		
			booktabs alignment(.) width(\hsize) replace type ///
			drop( * ) ///			
			noline nogaps fragment nonum nomtitles

end
capture program drop table_A2	
program table_A2	
	use $data , clear
	capture drop temp*
	//generate pre-treatment means
	keep if year>1986 & year <1990
	*generate difference in logs from two years prior	
	foreach i in ln_mwh ln_labor ln_ncap plant_age {
		gen pre_dif_`i' = `i'-l2.`i'
	}
	//generate average variable values over pre-treatment period
	foreach i of glo sum_vars { 
		bysort plantid: egen pre_`i' = mean(`i') 
		drop `i'
		ren pre_`i' `i'
	}
	
	
	replace NOx_RACT = 2 if s1m == 1 //create second 'treatment' for plants in 
	//o3 nonattainment areas not subject to NOx RACT
	bysort plantid: egen pre_NOx_RACT = mean(NOx_RACT)
	drop NOx_RACT
	ren pre_NOx_RACT NOx_RACT
	
	
	keep if year==1989

	eststo clear
	*levels
	

		estpost tabstat $sum_vars ///			
		if NOx_RACT==0 & ln_labor !=. , ///
			stat(mean sd)  columns(statistics)  
		eststo am
		sca n0 = e(N)
		estpost tabstat $sum_vars ///
			if NOx_RACT==2 & ln_labor !=. , ///
			stat(mean sd)  columns(statistics)
		eststo nm1
		sca n1 = e(N)
		estpost tabstat $sum_vars ///
			if NOx_RACT==1 & ln_labor !=. , ///
			stat(mean sd)  columns(statistics)
		eststo nm2
		sca n2 = e(N)
		estpost ttest $sum_vars ///
			if NOx_RACT == 0 | NOx_RACT == 2  , by(NOx_RACT) unequal
			matrix mean=e(b)
			estadd matrix mean
			matrix sd=e(t)
			estadd matrix sd
		eststo tan1
		estpost ttest $sum_vars ///
			if NOx_RACT == 0 | NOx_RACT == 1  , by(NOx_RACT) unequal
			matrix mean=e(b)
			estadd matrix mean
			matrix sd=e(t)
			estadd matrix sd
		eststo tan2
	*differences
		drop ln_mwh ln_labor ln_ncap  plant_age
		renvars pre_dif_ln_mwh pre_dif_ln_labor pre_dif_ln_ncap  pre_dif_plant_age \ ///
			ln_mwh ln_labor ln_ncap  plant_age
		estpost tabstat ln_labor ln_mwh ln_ncap   plant_age  ///			
		if NOx_RACT==0 , ///
			stat(mean sd)  columns(statistics)  
		eststo ad
		sca n0d = e(N)
		estpost tabstat ln_labor ln_mwh ln_ncap   plant_age   ///
			if NOx_RACT==2 , ///
			stat(mean sd)  columns(statistics)
		eststo nd1
		sca n1d = e(N)
		estpost tabstat ln_labor ln_mwh ln_ncap   plant_age   ///
			if NOx_RACT==1 , ///
			stat(mean sd)  columns(statistics)
		eststo nd2
		sca n2d = e(N)
		estpost ttest ln_labor ln_mwh ln_ncap   plant_age if NOx_RACT == 0 | NOx_RACT == 2 ///
			, by(NOx_RACT) unequal
			matrix mean=e(b)
			estadd matrix mean
			matrix sd=e(t)
			estadd matrix sd
		eststo tand1
		estpost ttest ln_labor ln_mwh ln_ncap   plant_age if NOx_RACT == 0 | NOx_RACT == 1 ///
			, by(NOx_RACT) unequal
			matrix mean=e(b)
			estadd matrix mean
			matrix sd=e(t)
			estadd matrix sd
		eststo tand2
	
		capture file close latex
		file open latex using non_obs_s1m${so2}.txt, write replace
			file write latex "Plants & \multicolumn{1}{c}{" (n0) "} & \multicolumn{1}{c}{" (n2) "}" 
			file write latex "&\multicolumn{1}{c}{" (n1) "}" 
			file write latex " \\" _n
		file close latex
		file open latex using non_obsb_s1m${so2}.txt, write replace
			file write latex "Plants & \multicolumn{1}{c}{" (n0d) "} & \multicolumn{1}{c}{" (n2d) "}" 
			file write latex "&\multicolumn{1}{c}{" (n1d) "}" 
			file write latex " \\" _n
		file close latex
		esttab am nm2 nm1 tan2 tan1 using sumstat_s1m${so2}.tex, main(mean) b(%5.3f) aux(sd) star unstack nonum nonote ///
			varlabels(${sum_lab}   ) ///
			nomtitles ///
			booktabs alignment(.) width(\hsize) replace type  ///
				noline  nogaps fragment 	noobs not label
		esttab ad nd2 nd1 tand2 tand1 using sumstatb_s1m${so2}.tex, main(mean) b(%5.3f) aux(sd) star unstack nonum nonote ///
			varlabels(${sum_lab}  ) ///
			nomtitles ///
			booktabs alignment(.) width(\hsize) replace type  ///
				noline  nogaps fragment 	noobs not label
		eststo clear
	
end
